@@ -21,9 +21,9 @@ enum {
     opt_batch,
     opt_cert_digest_algo,
     opt_cert_notation,
-    opt_charset,
     opt_cipher_algo,
     opt_clearsign,
+    opt_clear_sign,
     opt_command_fd,
     opt_comment,
     opt_compress_algo,
@@ -97,12 +97,14 @@ enum {
     opt_try_secret_key,
     opt_unwrap,
     opt_use_agent,
+    opt_utf8_strings,
     opt_verify,
     opt_verify_options,
     opt_version,
     opt_with_colons,
     opt_with_fingerprint,
     opt_with_keygrip,
+    opt_with_secret,
 };
 
 int parse_options(int argc, char *argv[], int *input_fds,
@@ -133,15 +135,14 @@ static const int gpg_allowed_options[] = {
     opt_always_trust,
     opt_batch,
     opt_cert_notation,
-    opt_charset,
     opt_clearsign,
+    opt_clear_sign,
     opt_command_fd,
     opt_comment,
     opt_compress_algo,
     opt_default_recipient_self,
     opt_digest_algo,
     opt_disable_mdc,
-    opt_display_charset,
     opt_emit_version,
     opt_enable_progress_filter,
     opt_encrypt_to,
@@ -210,6 +211,7 @@ static const int gpg_allowed_options[] = {
     opt_with_colons,
     opt_with_fingerprint,
     opt_with_keygrip,
+    opt_with_secret,
     0
 };
 
@@ -231,6 +233,7 @@ static const struct gpg_command_opt gpg_commands[] = {
     {'k', true},
     {'s', false},
     {opt_clearsign, false},
+    {opt_clear_sign, false},
     {opt_export, true},
     {opt_export_ssh, true},
     {opt_fingerprint, true},
@@ -241,7 +244,7 @@ static const struct gpg_command_opt gpg_commands[] = {
     {0, false},
 };
 
-static const char gpg_short_options[] = "+bacdekKnN:qr:R:stu:";
+static const char gpg_short_options[] = "+bacdekKnN:o:qr:R:stu:";
 
 static const struct option gpg_long_options[] = {
     {"always-trust", 0, 0, opt_always_trust},
@@ -249,9 +252,10 @@ static const struct option gpg_long_options[] = {
     {"batch", 0, 0, opt_batch},
     {"cert-digest-algo", 1, 0, opt_cert_digest_algo},
     {"cert-notation", 1, 0, opt_cert_notation},
-    {"charset", 1, 0, opt_charset},
+    {"charset", 1, 0, opt_display_charset},
     {"cipher-algo", 1, 0, opt_cipher_algo},
     {"clearsign", 0, 0, opt_clearsign},
+    {"clear-sign", 0, 0, opt_clear_sign},
     {"command-fd", 1, 0, opt_command_fd},
     {"comment", 1, 0, opt_comment},
     {"compress-algo", 1, 0, opt_compress_algo},
@@ -341,6 +345,7 @@ static const struct option gpg_long_options[] = {
     {"try-all-secrets", 0, 0, opt_try_all_secrets},
     {"unwrap", 0, 0, opt_unwrap},
     {"use-agent", 0, 0, opt_use_agent},
+    {"utf8-strings", 0, 0, opt_utf8_strings},
     {"verify", 0, 0, opt_verify},
     {"verify-options", 1, 0, opt_verify_options},
     {"verbose", 0, 0, 'v'},
@@ -348,6 +353,7 @@ static const struct option gpg_long_options[] = {
     {"with-colons", 0, 0, opt_with_colons},
     {"with-fingerprint", 0, 0, opt_with_fingerprint},
     {"with-keygrip", 0, 0, opt_with_keygrip},
+    {"with-secret", 0, 0, opt_with_secret},
     {0, 0, 0, 0}
 };
 
